==> rc-ui-lib-0.1.51.tgz: package/lib/circle/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _ = require("..");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Circle', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.clearAllMocks();
  });
  it('should update to final rate immediately if speed is 0', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 0,
              speed: 0
            }));
            _context.next = 3;
            return wrapper.setProps({
              rate: 150
            });

          case 3:
            expect(wrapper.props().rate).toEqual(150);
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 5:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should emit "update:currentRate" event during animation', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              rate: 50,
              defaultRate: 0,
              speed: 100
            }));
            expect(wrapper.props().rate).toEqual(50);
            _context2.next = 4;
            return wrapper.setProps({
              rate: 150
            });

          case 4:
            expect(wrapper.props().rate).toEqual(150);
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should change circle size when using size prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 0,
              size: 100
            }));
            expect(wrapper.getDOMNode().style.width).toEqual('100px');
            expect(wrapper.getDOMNode().style.height).toEqual('100px');
            _context3.next = 5;
            return wrapper.setProps({
              size: 150
            });

          case 5:
            expect(wrapper.getDOMNode().style.width).toEqual('150px');
            expect(wrapper.getDOMNode().style.height).toEqual('150px');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 8:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should change stroke linecap when using stroke-linecap prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 0,
              strokeLinecap: "square"
            }));
            expect(wrapper.find('.rc-circle__hover').getDOMNode().style.strokeLinecap).toEqual('square');
            _context4.next = 4;
            return wrapper.setProps({
              strokeLinecap: 'butt'
            });

          case 4:
            wrapper.update();
            expect(wrapper.find('.rc-circle__hover').getDOMNode().style.strokeLinecap).toEqual('butt');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 7:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render start-position prop correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              startPosition: "top"
            }));
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('');
            _context5.next = 4;
            return wrapper.setProps({
              startPosition: 'right'
            });

          case 4:
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('rotate(90deg)');
            _context5.next = 7;
            return wrapper.setProps({
              startPosition: 'bottom'
            });

          case 7:
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('rotate(180deg)');
            _context5.next = 10;
            return wrapper.setProps({
              startPosition: 'left'
            });

          case 10:
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('rotate(270deg)');

          case 11:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render text correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 70,
              text: "70%"
            }));
            expect(wrapper.find('.rc-circle__text').text()).toEqual('70%');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 3:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render linearGradient correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 70,
              color: {
                '0%': '#3fecff',
                '100%': '#6149f6'
              }
            }));
            expect(wrapper.find('stop').at(0).props().stopColor).toEqual('#3fecff');
            expect(wrapper.find('stop').at(1).props().stopColor).toEqual('#6149f6');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 4:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render clockwise and anticlockwise correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 70,
              clockwise: true,
              text: "70%"
            }));
            expect(wrapper.find('svg').find('path').at(1).props().d.substr(-10, 1)).toEqual('1');
            _context8.next = 4;
            return wrapper.setProps({
              clockwise: false
            });

          case 4:
            expect(wrapper.find('svg').find('path').at(1).props().d.substr(-10, 1)).toEqual('0');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 6:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/lib/circle/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _utils = require("../../../tests/utils");

var _ = require("..");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Circle', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should update to final rate immediately if speed is 0', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var onChange;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              rate: 50,
              speed: 0,
              onChange: onChange
            })); // await wrapper.setProps({ rate: 150 });
            // expect(wrapper.props().rate).toEqual(150);

            _context.next = 4;
            return (0, _utils.sleep)(50);

          case 4:
            expect(onChange).toHaveBeenCalledWith(50); // expect(toJson(wrapper)).toMatchSnapshot();

          case 5:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render rate correctly when rate is changed', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              rate: 50,
              defaultRate: 0
            }));
            expect(wrapper.props().rate).toEqual(50);
            _context2.next = 4;
            return wrapper.setProps({
              rate: 150
            });

          case 4:
            expect(wrapper.props().rate).toEqual(150);
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should change circle size when using size prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 0,
              size: 100
            }));
            expect(wrapper.getDOMNode().style.width).toEqual('100px');
            expect(wrapper.getDOMNode().style.height).toEqual('100px');
            _context3.next = 5;
            return wrapper.setProps({
              size: 150
            });

          case 5:
            expect(wrapper.getDOMNode().style.width).toEqual('150px');
            expect(wrapper.getDOMNode().style.height).toEqual('150px');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 8:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should change stroke linecap when using stroke-linecap prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 0,
              strokeLinecap: "square"
            }));
            expect(wrapper.find('.rc-circle__hover').getDOMNode().style.strokeLinecap).toEqual('square');
            _context4.next = 4;
            return wrapper.setProps({
              strokeLinecap: 'butt'
            });

          case 4:
            wrapper.update();
            expect(wrapper.find('.rc-circle__hover').getDOMNode().style.strokeLinecap).toEqual('butt');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 7:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render start-position prop correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              startPosition: "top"
            }));
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('');
            _context5.next = 4;
            return wrapper.setProps({
              startPosition: 'right'
            });

          case 4:
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('rotate(90deg)');
            _context5.next = 7;
            return wrapper.setProps({
              startPosition: 'bottom'
            });

          case 7:
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('rotate(180deg)');
            _context5.next = 10;
            return wrapper.setProps({
              startPosition: 'left'
            });

          case 10:
            expect(wrapper.find('svg').getDOMNode().style.transform).toEqual('rotate(270deg)');

          case 11:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render text correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 70,
              text: "70%"
            }));
            expect(wrapper.find('.rc-circle__text').text()).toEqual('70%');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 3:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render linearGradient correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 70,
              color: {
                '0%': '#3fecff',
                '100%': '#6149f6'
              }
            }));
            expect(wrapper.find('stop').at(0).props().stopColor).toEqual('#3fecff');
            expect(wrapper.find('stop').at(1).props().stopColor).toEqual('#6149f6');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 4:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render clockwise and anticlockwise correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              defaultRate: 70,
              clockwise: true,
              text: "70%"
            }));
            expect(wrapper.find('svg').find('path').at(1).props().d.substr(-10, 1)).toEqual('1');
            _context8.next = 4;
            return wrapper.setProps({
              clockwise: false
            });

          case 4:
            expect(wrapper.find('svg').find('path').at(1).props().d.substr(-10, 1)).toEqual('0');
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 6:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render layerColor correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
      defaultRate: 70,
      layerColor: "#ebedf0"
    }));
    expect(wrapper.find('.rc-circle__layer').getDOMNode().style.stroke).toEqual('#ebedf0');
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should render fill prop correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
      defaultRate: 70,
      fill: "#ff0000"
    }));
    expect(wrapper.find('.rc-circle__layer').getDOMNode().style.fill).toEqual('#ff0000');
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('hould emit onChange event during animation', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    var onChange;
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.Circle, {
              speed: 150,
              rate: 150,
              onChange: onChange
            }));
            _context9.next = 4;
            return (0, _utils.sleep)(50);

          case 4:
            expect(onChange).toHaveBeenCalled();

          case 5:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});
